%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% summarize_results:
%
% Assuming that log files were generated using 'generate_simulations' and
% 'test_simulations', this generates a summary of the output. Hopefully
% parameters such as 'sample_size_space' are self-explanatory.
%
% Created by: Ricardo Silva, London
% University College London
% Current version: 01/06/2012

PATH_TRIAL = '.';  % Where data files are
PATH_RESULT = '.'; % Where log files are

load('X_files.mat');
cutoff = 25;
num_iterations = 20;

sample_size_space = [1000 5000 10000];

summary_diff_coeff = cell(length(sample_size_space), 1);
summary_diff_om = cell(length(sample_size_space), 1);
summary_diff_com = cell(length(sample_size_space), 1);
summary_diff_time = cell(length(sample_size_space), 1);

for i = 1:length(sample_size_space)
  summary_diff_coeff{i} = zeros(num_iterations, 2);
  summary_diff_om{i} = zeros(num_iterations, 2);
  summary_diff_com{i} = zeros(num_iterations, 2);
  summary_diff_time{i} = zeros(num_iterations, 1);
end

s_count = 1;

for sample_size = sample_size_space
    
  for i = 1:num_iterations
  
    fprintf('\n** RESULTS FOR TRIAL %d\n', i)
  
    filename = strcat(PATH_TRIAL, '\synth', int2str(i), '.mat');
    load(filename)  
    filename = strcat(PATH_RESULT, '\result_synth_', int2str(sample_size), '_', int2str(i), '.mat');
    load(filename)
  
    num_y = size(L1, 1);
    num_x = max(Y_parents);
  
    M = 50; K = 40;
    X_children = cell(num_x, 1);
    for x = 1:num_x
      X_children{x} = find(Y_parents == x);
    end
    sd_r = 1; p_G = 0.1;
    true_cov_X_approx = project_rho(true_cov_X, rho_domain);
  
    possible_com = sum(sum((1 - bidir_graph) - eye(num_y))) / 2;
    possible_om =  sum(sum(bidir_graph)) / 2;
  
    error_cov1 = sqrt(sum(sum((abs(rho_X1) - abs(true_cov_X)).^2))) / (num_x * (num_x - 1));
    error_cov2 = sqrt(sum(sum((abs(rho_X2) - abs(true_cov_X)).^2))) / (num_x * (num_x - 1));
    error_cov3 = sqrt(sum(sum((abs(rho_X3) - abs(true_cov_X)).^2))) / (num_x * (num_x - 1));
    err_L1 = sqrt(mean((abs(L_true(:, 1)) - abs(L1(:, 1))).^2));
    err_L2 = sqrt(mean((abs(L_true(:, 1)) - abs(L2(:, 1))).^2));
    err_L3 = sqrt(mean((abs(L_true(:, 1)) - abs(L3(:, 1))).^2));
      
    disp([num_o1 num_o2 num_o3; num_c1 num_c2 num_c3])

    disp([num_o1 / possible_om  num_o2 / possible_om  num_o3 / possible_om; ...
          num_c1 / possible_com num_c2 / possible_com num_c3 / possible_com; ...
          score1                score2                score3; ...
          err_L1                err_L2                err_L3; ...
          error_cov1            error_cov2            error_cov3])
   
    fprintf('Time for Type 1 model: %f\n', time1); 
    fprintf('Time for Type 2 model: %f\n', time2); 
    fprintf('Time for Type 3 model: %f\n', time3); 
  
    summary_diff_coeff{s_count}(i, 1) = err_L2 - err_L1;
    summary_diff_coeff{s_count}(i, 2) = err_L3 - err_L1;
    summary_diff_om{s_count}(i, 1)   = (num_o2 - num_o1) / possible_om;
    summary_diff_om{s_count}(i, 2)   = (num_o3 - num_o1) / possible_om;
    summary_diff_com{s_count}(i, 1)  = (num_c2 - num_c1) / possible_com;
    summary_diff_com{s_count}(i, 2)  = (num_c3 - num_c1) / possible_com;
    summary_diff_time{s_count}(i)    = time1 / time2;

    score_true = test_score(Y, X_children, p_G, sd_r, X_v, X_ws, ...
                    rho_domain, M, L_true, true_cov_X_approx, bidir_graph);
    fprintf('Score of true graph = %f\n', score_true)
    
  end
  
  s_count = s_count + 1;

end

graph_titles = cell(3, 1);
graph_titles{1} = 'Slope error';
graph_titles{2} = 'Omission error';
graph_titles{3} = 'Commission error';
for k = 1:3
  switch k
    case 1
      summary_diff_target = summary_diff_coeff;
    case 2
      summary_diff_target = summary_diff_om;  
    case 3
      summary_diff_target = summary_diff_com;    
  end
  stat_graph = zeros(2 * length(sample_size_space) * num_iterations, 2);
  count_e = 1;
  for i = 1:length(sample_size_space)
    i_interval = ((i - 1) * 2 * num_iterations + 1):(i * 2 * num_iterations);
    stat_graph(i_interval, 1) = [summary_diff_target{i}(:, 1); summary_diff_target{i}(:, 2)];
    stat_graph(i_interval, 2) = [count_e * ones(num_iterations, 1); 
                                 (count_e + 1)* ones(num_iterations, 1)];   
    count_e = count_e + 2;
  end
  stat_graph = stat_graph + randn(size(stat_graph)) * 0.001; % Jitter

  figure
  scatter(stat_graph(:, 2), stat_graph(:, 1))
  set(gca, 'xlim', [0.5, 0.5 + 2 * length(sample_size_space)])
  hline = refline([0 0]);
  set(hline, 'Color', 'r', 'LineStyle', '--')
  set(gca, 'XTickLabel', '1000-I|1000-0|5000-I|5000-0|10000-I|10000-0')
  set(gca, 'XMinorGrid', 'off')
  set(gca, 'FontSize', 12)
  title(graph_titles{k}, 'FontSize', 32)
    
  for i = 1:length(sample_size_space)
    p2 = signrank(summary_diff_target{i}(:, 1));
    p0 = signrank(summary_diff_target{i}(:, 2));  
    fprintf(strcat('Testing[', graph_titles{k}, ...
            ', sample size = %d]: [%f %f]\n'), sample_size_space(i), p2, p0);
  end
  
  for i = 1:length(sample_size_space)
    s2 = sum(summary_diff_target{i}(:, 1) > 0);
    s0 = sum(summary_diff_target{i}(:, 2) > 0);  
    fprintf(strcat('Number[', graph_titles{k}, ...
            ', sample size = %d]: [%d %d]\n'), sample_size_space(i), s2, s0);
  end

end

