%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% test_simulations:
%
% Loads synthetic data and evaluate the outcome on both versions of the
% algorithm.
%
% Created by: Ricardo Silva, London, 20/03/2012
% University College London
% Current version: 20/03/2012

load('X_files.mat') % Points for X
load('seed_file.mat')
rng(s)

num_simulations = 1;
sample_size = 5000;

for i = 1:num_simulations
    
  fprintf('** TRYING FILE BATCH #%d\n', i);
  filename = strcat('synth', int2str(i), '.mat');
  load(filename)
  Y = Y(1:sample_size, :);
  
  Y_counts = binary_sufficient(Y);
  
  sd_r = 1; p_G = 0.1;
  M = 50; K = 40;
  num_x = max(Y_parents);
  X_children = cell(num_x, 1);
  for x = 1:num_x
    X_children{x} = find(Y_parents == x);
  end
  num_y = size(Y, 2);   
  
  filename_save = strcat('result_temp', int2str(i), '.mat');

  % Variation 0: single-shot learning, no iteration
  
  time3_start = tic;
  [H3 L3 rho_X3 score3 pair_scores3] = ...
        learn_structure_mcdn_simple(Y, Y_counts, X_children, p_G, ...
              sd_r, X_v, X_ws, rho_domain, M);
  time3 = toc(time3_start);            
  save(filename_save, 'H3', 'L3', 'rho_X3', 'score3', 'time3_start', 'time3')

  % Variation 1: EM-based method which integrates over copula parameters
  % generated from a two-latent region
  
  time1_start = tic;
  [H1 L1 rho_X1 score1 pair_scores1 num_iter1] = ...
        learn_structure_mcdn_final(H3, L3, rho_X3, ...
              Y, Y_counts, X_children, p_G, K, ...
              sd_r, X_v, X_ws, rho_domain, M, true);
  time1 = toc(time1_start);                             
  save(filename_save, 'H1', 'L1', 'rho_X1', 'score1', 'time1_start', 'time1')
  
  % Variation 2: plain composite likelihood method 
  
  time2_start = tic;
  [H2 L2 rho_X2 score2 pair_scores2 num_iter2] = ...
        learn_structure_mcdn_final(H3, L3, rho_X3, ...
              Y, Y_counts, X_children, p_G, K, ...
              sd_r, X_v, X_ws, rho_domain, M, false);
  time2 = toc(time2_start);
  save(filename_save, 'H2', 'L2', 'rho_X2', 'score2', 'time2_start', 'time2')
  
  % Evaluation
  
  omission1 = bidir_graph > H1; commission1 = bidir_graph < H1;  
  omission2 = bidir_graph > H2; commission2 = bidir_graph < H2;
  omission3 = bidir_graph > H3; commission3 = bidir_graph < H3;
  num_o1 = sum(sum(omission1)) / 2; num_c1 = sum(sum(commission1)) / 2; 
  num_o2 = sum(sum(omission2)) / 2; num_c2 = sum(sum(commission2)) / 2;
  num_o3 = sum(sum(omission3)) / 2; num_c3 = sum(sum(commission3)) / 2;
   
  filename_save = strcat('result_synth_', int2str(sample_size), '_', int2str(i), '.mat');
  save(filename_save, 'H1', 'L1', 'rho_X1', 'H2', 'L2', 'rho_X2', ...
       'omission1', 'omission2', 'commission1', 'commission2', ...
       'num_o1', 'num_o2', 'num_c1', 'num_c2', ...
       'score1', 'score2', 'pair_scores1', 'pair_scores2', ...
       'H3', 'L3', 'rho_X3', 'score3', 'pair_scores3', ...
       'num_o3', 'num_c3', ...
       'time1_start', 'time1', 'time2_start', 'time2', 'time3_start', 'time3', ...
       'num_iter1', 'num_iter2');

end

disp('DONE')
