%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% count_types:
%
% Generates counts for all possible combinations of binary values. This
% assumes the dimensionality is small (< 20).
%
% Input:
%
% - Y: the data, binary encoded as -1s and 1s
%   
% Output:
% 
% - distr: a 2^|Y| vector containing the respective counts
%
% Created by: Ricardo Silva, London, 14/02/2012
% University College London
% Current version: 14/02/2012

function distr = count_types(Y)

[N num_y] = size(Y);
distr = zeros(2^num_y, 1);

weights = (2.^((num_y - 1):-1:0))';
Y_code = ((Y + 1) / 2) * weights + 1;

for n = 1:N
  distr(Y_code(n)) = distr(Y_code(n)) + 1;
end

