%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% graph_edge_list:
%
% Transforms a matrix-represented graph into an edge list representation.
%
% Input:
%
% - G: the graph matrix
%   
% Output:
% 
% - edges: the matrix of edges
%
% Created by: Ricardo Silva, London, 20/02/2012
% University College London
% Current version: 20/02/2012

function edges = graph_edge_list(G)

num_y = size(G, 1);
num_edges = sum(sum(G)) / 2;
edges = zeros(num_edges, 2);
edge_count = 1;

for y = 1:num_y
  adj = find(G(y, :) == 1);
  adj = adj(adj > y);
  for e = adj
    edges(edge_count, :) = [y e];
    edge_count = edge_count + 1;
  end
end
