%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% project_rho:
%
% Generates an approximate correlation matrix by changing each entry to the
% corresponding closest match in a pre-defined grid of correlation values.
% The output is NOT guaranteed to be positive definite.
%
% Input:
%
% - rho: the correlation matrix
% - rho_domain: acceptable values
%
% Output:
% 
% - new_rho: "closest match" matrix
%
% Created by: Ricardo Silva, London, 18/03/2012
% University College London
% Current version: 18/03/2012

function new_rho = project_rho(rho, rho_domain)

num_v = size(rho, 1);
new_rho = eye(num_v);

for v1 = 1:num_v
  for v2 = (v1 + 1):num_v
    best_true_dist = Inf;
    for r = rho_domain
      d_r = abs(r - rho(v1, v2));
      if d_r < best_true_dist && r * rho(v1, v2) >= 0
        best_rho = r;
        best_true_dist = d_r;
      end
    end
    new_rho(v1, v2) = best_rho;
    new_rho(v2, v1) = best_rho;
  end
end
